Skip to contents

Implementation of the unit normal and unit length scaling methods to produce standardized regression coefficients.

Usage

standardization(x, type = c("normal", "length"))

Arguments

x

a vector containing the values to be scaled (unit normal scaling and unit length scales)

type

type of scaling to be applied.

Value

a vector with the standardized variable