Skip to contents

ANOVA table for linear models

Usage

tab_anova(model)

Arguments

model

an object of class lm or aov with the fitted linear model.

Value

the ANOVA table decomposed into model and error sources of variation.