Implementation of the unit normal and unit length scaling methods to produce standardized regression coefficients.
Usage
standardization(x, type = c("normal", "length"))Implementation of the unit normal and unit length scaling methods to produce standardized regression coefficients.
standardization(x, type = c("normal", "length"))