R/tab_anova.R
tab_anova.Rd
ANOVA table for linear models
tab_anova(model)
an object of class lm or aov with the fitted linear model.
the ANOVA table decomposed into model and error sources of variation.